==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/config/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 */
$lang['menu']                  = 'Parâmetros de Configuração';
$lang['error']                 = 'Parâmetros de Configuração não actualizados devido a valores inválidos. Por favor, reveja as modificações que pretende efectuar antes de re-submetê-las.<br /> Os valores incorrectos serão mostrados dentro de uma "moldura" vermelha.';
$lang['updated']               = 'Parâmetros de Configuração actualizados com sucesso.';
$lang['nochoice']              = '(não existem outras escolhas disponíveis)';
$lang['_configuration_manager'] = 'Gestor de Parâmetros de Configuração';
$lang['_header_dokuwiki']      = 'Parâmetros DokuWiki';
$lang['_header_plugin']        = 'Parâmetros dos Plugins';
$lang['_header_template']      = 'Parâmetros das Templates';
$lang['_header_undefined']     = 'Parâmetros não definidos';
$lang['_basic']                = 'Configurações Básicas';
$lang['_display']              = 'Configuração de Apresentação';
$lang['_authentication']       = 'Configuração de Autenticação';
$lang['_anti_spam']            = 'Configuração Anti-Spam';
$lang['_editing']              = 'Configuração de Edição';
$lang['_links']                = 'Configuração de Ligações';
$lang['_media']                = 'Configuração de Media';
$lang['_advanced']             = 'Configurações Avançadas';
$lang['_network']              = 'Configuração de Rede';
$lang['_plugin_sufix']         = 'Configuração dos Plugins';
$lang['_template_sufix']       = 'Configuração das Templates';
$lang['_msg_setting_no_default'] = 'Sem valor por omissão.';
$lang['fmode']                 = 'Modo de criação de ficheiros.';
$lang['dmode']                 = 'Modo de criação de pastas.';
$lang['lang']                  = 'Idioma';
$lang['basedir']               = 'Pasta Base';
$lang['baseurl']               = 'URL Base';
$lang['savedir']               = 'Pasta para guardar dados';
$lang['start']                 = 'Nome da Página Inicial';
$lang['title']                 = 'Título deste Wiki';
$lang['template']              = 'Template';
$lang['fullpath']              = 'Revelar caminho completo no rodapé';
$lang['recent']                = 'Alterações recentes';
$lang['breadcrumbs']           = 'Número máximo de breadcrumbs';
$lang['youarehere']            = 'Breadcrumbs hierárquicas';
$lang['typography']            = 'Executar substituições tipográficas';
$lang['htmlok']                = 'Permitir embeber HTML';
$lang['phpok']                 = 'Permitir embeber PHP';
$lang['dformat']               = 'Formato de Data (ver função PHP\'s <a href="http://www.php.net/strftime">strftime</a>)';
$lang['signature']             = 'Assinatura';
$lang['toptoclevel']           = 'Nível de topo para a tabela de conteúdo';
$lang['maxtoclevel']           = 'Máximo nível para a tabela de conteúdo';
$lang['maxseclevel']           = 'Máximo nível para editar secção';
$lang['camelcase']             = 'Usar CamelCase';
$lang['useacl']                = 'Usar ACL - Listas de Controlo de Acessos';
$lang['autopasswd']            = 'Auto-gerar senhas';
$lang['passcrypt']             = 'Método de cifragem da senha';
$lang['defaultgroup']          = 'Grupo por omissão';
$lang['disableactions']        = 'Desactivar acções DokuWiki';
$lang['disableactions_subscription'] = 'Subscrever/Não Subscrver';
$lang['disableactions_wikicode'] = 'Ver fonte/Exportar em bruto';
$lang['disableactions_other']  = 'Outras acções (separadas por vírgula)';
$lang['compression']           = 'Método de compressão para histórico';
$lang['cachetime']             = 'Idade máxima para cache (seg.)';
$lang['locktime']              = 'Idade máxima para locks (seg.)';
$lang['jpg_quality']           = 'Compressão/Qualidade JPG (0-100)';
$lang['sitemap']               = 'Gerar Sitemap Google (dias)';
$lang['typography_o_0']        = 'nenhum';
$lang['typography_o_1']        = 'Apenas entre aspas';
$lang['typography_o_2']        = 'Entre aspas e apóstrofes';
$lang['userewrite_o_0']        = 'nenhum';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'interno (DokuWiki)';
$lang['deaccent_o_1']          = 'remover acentos';
$lang['gdlib_o_1']             = 'Versão 1.x';
$lang['gdlib_o_2']             = 'Auto-detecção';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Abstracto';
$lang['rss_content_o_diff']    = 'Diferenças Unificadas';
$lang['rss_linkto_o_diff']     = 'vista de diferenças';
$lang['rss_linkto_o_page']     = 'página revista';
$lang['rss_linkto_o_rev']      = 'lista de revisões';
$lang['rss_linkto_o_current']  = 'página actual';
$lang['compression_o_0']       = 'Sem Compressão';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/config/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 */
$lang['menu']                  = 'Parâmetros de Configuração';
$lang['error']                 = 'Parâmetros de Configuração não actualizados devido a valores inválidos. Por favor, reveja as modificações que pretende efectuar antes de re-submetê-las.<br /> Os valores incorrectos serão mostrados dentro de uma "moldura" vermelha.';
$lang['updated']               = 'Parâmetros de Configuração actualizados com sucesso.';
$lang['nochoice']              = '(não existem outras escolhas disponíveis)';
$lang['_configuration_manager'] = 'Gestor de Parâmetros de Configuração';
$lang['_header_dokuwiki']      = 'Parâmetros DokuWiki';
$lang['_header_plugin']        = 'Parâmetros dos Plugins';
$lang['_header_template']      = 'Parâmetros das Templates';
$lang['_header_undefined']     = 'Parâmetros não definidos';
$lang['_basic']                = 'Configurações Básicas';
$lang['_display']              = 'Configuração de Apresentação';
$lang['_authentication']       = 'Configuração de Autenticação';
$lang['_anti_spam']            = 'Configuração Anti-Spam';
$lang['_editing']              = 'Configuração de Edição';
$lang['_links']                = 'Configuração de Ligações';
$lang['_media']                = 'Configuração de Media';
$lang['_advanced']             = 'Configurações Avançadas';
$lang['_network']              = 'Configuração de Rede';
$lang['_plugin_sufix']         = 'Configuração dos Plugins';
$lang['_template_sufix']       = 'Configuração das Templates';
$lang['_msg_setting_no_default'] = 'Sem valor por omissão.';
$lang['fmode']                 = 'Modo de criação de ficheiros.';
$lang['dmode']                 = 'Modo de criação de pastas.';
$lang['lang']                  = 'Idioma';
$lang['basedir']               = 'Pasta Base';
$lang['baseurl']               = 'URL Base';
$lang['savedir']               = 'Pasta para guardar dados';
$lang['start']                 = 'Nome da Página Inicial';
$lang['title']                 = 'Título deste Wiki';
$lang['template']              = 'Template';
$lang['fullpath']              = 'Revelar caminho completo no rodapé';
$lang['recent']                = 'Alterações recentes';
$lang['breadcrumbs']           = 'Número máximo de breadcrumbs';
$lang['youarehere']            = 'Breadcrumbs hierárquicas';
$lang['typography']            = 'Executar substituições tipográficas';
$lang['htmlok']                = 'Permitir embeber HTML';
$lang['phpok']                 = 'Permitir embeber PHP';
$lang['dformat']               = 'Formato de Data (ver função PHP\'s <a href="http://www.php.net/strftime">strftime</a>)';
$lang['signature']             = 'Assinatura';
$lang['toptoclevel']           = 'Nível de topo para a tabela de conteúdo';
$lang['maxtoclevel']           = 'Máximo nível para a tabela de conteúdo';
$lang['maxseclevel']           = 'Máximo nível para editar secção';
$lang['camelcase']             = 'Usar CamelCase';
$lang['useacl']                = 'Usar ACL - Listas de Controlo de Acessos';
$lang['autopasswd']            = 'Auto-gerar senhas';
$lang['passcrypt']             = 'Método de cifragem da senha';
$lang['defaultgroup']          = 'Grupo por omissão';
$lang['disableactions']        = 'Desactivar acções DokuWiki';
$lang['disableactions_check']  = 'Checar';
$lang['disableactions_subscription'] = 'Subscrever/Não Subscrver';
$lang['disableactions_nssubscription'] = 'Subscrever / Dessubscrever Espaço de Nome';
$lang['disableactions_wikicode'] = 'Ver fonte/Exportar em bruto';
$lang['disableactions_other']  = 'Outras acções (separadas por vírgula)';
$lang['compression']           = 'Método de compressão para histórico';
$lang['cachetime']             = 'Idade máxima para cache (seg.)';
$lang['locktime']              = 'Idade máxima para locks (seg.)';
$lang['gdlib']                 = 'Versão GD Lib';
$lang['jpg_quality']           = 'Compressão/Qualidade JPG (0-100)';
$lang['sitemap']               = 'Gerar Sitemap Google (dias)';
$lang['renderer__plugin']      = '%s (plugin)';
$lang['rss_type']              = 'Tipo de feed XML';
$lang['rss_linkto']            = 'Links de feed XML ara';
$lang['proxy____port']         = 'Porta de Proxy';
$lang['proxy____user']         = 'Nome de utilizador Proxy';
$lang['proxy____pass']         = 'Password de Proxy ';
$lang['typography_o_0']        = 'nenhum';
$lang['typography_o_1']        = 'Apenas entre aspas';
$lang['typography_o_2']        = 'Entre aspas e apóstrofes';
$lang['userewrite_o_0']        = 'nenhum';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'interno (DokuWiki)';
$lang['deaccent_o_0']          = 'desligado';
$lang['deaccent_o_1']          = 'remover acentos';
$lang['gdlib_o_1']             = 'Versão 1.x';
$lang['gdlib_o_2']             = 'Auto-detecção';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Abstracto';
$lang['rss_content_o_diff']    = 'Diferenças Unificadas';
$lang['rss_linkto_o_diff']     = 'vista de diferenças';
$lang['rss_linkto_o_page']     = 'página revista';
$lang['rss_linkto_o_rev']      = 'lista de revisões';
$lang['rss_linkto_o_current']  = 'página actual';
$lang['compression_o_0']       = 'Sem Compressão';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
